@@ -31,10 +31,11 @@ Albums::Albums(int artistId, XbmcModel *parent) :
 {
     QVariantMap params;
     if(artistId != -1) {
-      params.insert("artistid", artistId);
+        params.insert("artistid", artistId);
     }
     QVariantList properties;
     properties.append("artist");
+    properties.append("thumbnail");
     params.insert("properties", properties);
 
     QVariantMap sort;
@@ -42,7 +43,7 @@ Albums::Albums(int artistId, XbmcModel *parent) :
     sort.insert("order", "ascending");
     sort.insert("ignorearticle", true);
     params.insert("sort", sort);
-    m_request = XbmcConnection::sendCommand("AudioLibrary.GetAlbums", params);
+    m_requestList.insert(XbmcConnection::sendCommand("AudioLibrary.GetAlbums", params), RequestList);
     connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReceived(int,QVariantMap)));
 }
 
@@ -50,43 +51,76 @@ Albums::~Albums()
 {
 }
 
+void Albums::fetchItemDetails(int index)
+{
+    QVariantMap params;
+    params.insert("albumid", m_list.at(index)->data(RoleAlbumId).toInt());
+
+    QVariantList properties;
+//    properties.append("title");
+    properties.append("description");
+//    properties.append("artist");
+    properties.append("genre");
+//    properties.append("theme");
+//    properties.append("mood");
+//    properties.append("style");
+//    properties.append("type");
+//    properties.append("albumlabel");
+    properties.append("rating");
+    properties.append("year");
+//    properties.append("musicbrainzalbumid");
+//    properties.append("musicbrainzalbumartistid");
+//    properties.append("fanart");
+//    properties.append("thumbnail");
+//    properties.append("artistid");
+
+    params.insert("properties", properties);
+
+    connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReceived(int,QVariantMap)));
+    int id = XbmcConnection::sendCommand("AudioLibrary.GetAlbumDetails", params);
+    m_requestList.insert(id, RequestDetails);
+    m_detailsRequestMap.insert(id, index);
+}
+
 void Albums::responseReceived(int id, const QVariantMap &rsp)
 {
-    if(id != m_request) {
+    if(!m_requestList.contains(id)) {
         return;
     }
 
-    QList<QStandardItem*> list;
-    qDebug() << "got albums:" << rsp.value("result");
-    QVariantList responseList = rsp.value("result").toMap().value("albums").toList();
-    foreach(const QVariant &itemVariant, responseList) {
-        QVariantMap itemMap = itemVariant.toMap();
-        QStandardItem *item = new QStandardItem();
-        item->setText(itemMap.value("label").toString());
-        item->setData(itemMap.value("artist").toString(), RoleSubtitle);
-        item->setData(itemMap.value("albumid").toInt(), RoleAlbumId);
-        list.append(item);
-    }
-    beginInsertRows(QModelIndex(), 0, list.count() - 1);
-    m_list = list;
-    endInsertRows();
-}
+    switch(m_requestList.value(id)) {
+    case RequestList: {
+        QList<XbmcModelItem*> list;
+        qDebug() << "got albums:" << rsp.value("result");
+        QVariantList responseList = rsp.value("result").toMap().value("albums").toList();
+        foreach(const QVariant &itemVariant, responseList) {
+            QVariantMap itemMap = itemVariant.toMap();
+            LibraryItem *item = new LibraryItem();
+            item->setTitle(itemMap.value("label").toString());
+            item->setSubtitle(itemMap.value("artist").toString());
+            item->setAlbumId(itemMap.value("albumid").toInt());
+            item->setThumbnail(itemMap.value("thumbnail").toString());
+            item->setFileType("directory");
+            item->setPlayable(true);
+            item->setIgnoreArticle(true);
 
-int Albums::rowCount(const QModelIndex &parent) const
-{
-    Q_UNUSED(parent)
-    return m_list.count();
-}
-
-QVariant Albums::data(const QModelIndex &index, int role) const
-{
-    switch(role) {
-    case RoleFileType:
-        return "directory";
-    case RolePlayable:
-        return true;
+            list.append(item);
+        }
+        beginInsertRows(QModelIndex(), 0, list.count() - 1);
+        m_list = list;
+        endInsertRows();
+        }
+        break;
+    case RequestDetails:
+        qDebug() << "got item details:" << rsp;
+        LibraryItem *item = qobject_cast<LibraryItem*>(m_list.at(m_detailsRequestMap.value(id)));
+        QVariantMap details = rsp.value("result").toMap().value("albumdetails").toMap();
+        item->setDescription(details.value("description").toString());
+        item->setRating(details.value("rating").toInt());
+        item->setGenre(details.value("genre").toString());
+        item->setYear(details.value("year").toString());
+        emit dataChanged(index(m_detailsRequestMap.value(id), 0, QModelIndex()), index(m_detailsRequestMap.value(id), 0, QModelIndex()));
     }
-    return m_list.at(index.row())->data(role);
 }
 
 XbmcModel* Albums::enterItem(int index)
