@@ -19,15 +19,16 @@
 #include "audioplaylist.h"
 
 #include "xbmcconnection.h"
+#include "xdebug.h"
 
 AudioPlaylist::AudioPlaylist(Player *parent):
     Playlist(parent)
 {
 }
 
-QString AudioPlaylist::namespaceString() const
+int AudioPlaylist::playlistId() const
 {
-    return "AudioPlaylist";
+    return 0;
 }
 
 int AudioPlaylist::rowCount(const QModelIndex &parent) const
@@ -36,42 +37,42 @@ int AudioPlaylist::rowCount(const QModelIndex &parent) const
     return m_itemList.count();
 }
 
-//void AudioPlaylist::addItems(const PlaylistItem &item) const
-//{
-
-//}
-
 void AudioPlaylist::refresh()
 {
+    xDebug(XDAREA_PLAYLIST) << "Refreshing playlist" << playlistId();
     QVariantMap params;
-    QVariantList fields;
-    fields.append("duration");
-    fields.append("artist");
-    fields.append("album");
-    params.insert("fields", fields);
+    QVariantList properties;
+    properties.append("duration");
+    properties.append("artist");
+    properties.append("album");
+    params.insert("properties", properties);
 
-    int id = XbmcConnection::sendCommand(namespaceString() + ".GetItems", params);
+    params.insert("playlistid", playlistId());
+
+    int id = XbmcConnection::sendCommand("Playlist.GetItems", params);
     m_requestMap.insert(id, RequestGetItems);
 }
 
 void AudioPlaylist::queryItemData(int index)
 {
     QVariantMap params;
-    QVariantList fields;
-    fields.append("title");
-    fields.append("artist");
-    fields.append("album");
-    fields.append("fanart");
-    fields.append("thumbnail");
-    fields.append("duration");
-    params.insert("fields", fields);
+    QVariantList properties;
+    properties.append("title");
+    properties.append("artist");
+    properties.append("album");
+    properties.append("fanart");
+    properties.append("thumbnail");
+    properties.append("duration");
+    params.insert("properties", properties);
 
     QVariantMap limits;
     limits.insert("start", index);
     limits.insert("end", index + 1);
     params.insert("limits", limits);
+    params.insert("playlistid", playlistId());
 
-    int id = XbmcConnection::sendCommand(namespaceString() + ".GetItems", params);
+    xDebug(XDAREA_PLAYLIST) << "Gettin current item data" << params;
+    int id = XbmcConnection::sendCommand("Playlist.GetItems", params);
     m_requestMap.insert(id, RequestCurrentData);
 }
 
@@ -84,12 +85,11 @@ void AudioPlaylist::responseReveiced(int id, const QVariantMap &response)
 
     QVariant rsp = response.value("result");
 
-//    qDebug() << "AudioPlaylist response:" << rsp;
+//    xDebug(XDAREA_PLAYLIST) << "AudioPlaylist response:" << rsp;
 
     switch(m_requestMap.value(id)) {
     case RequestGetItems: {
-//        qDebug() << "got GetItems response:" << response;
-//        qDebug() << "resetting model";
+        xDebug(XDAREA_PLAYLIST) << "got GetItems response:" << response;
         beginResetModel();
         while(!m_itemList.isEmpty()){
             delete m_itemList.takeFirst();
@@ -98,43 +98,22 @@ void AudioPlaylist::responseReveiced(int id, const QVariantMap &response)
         foreach(const QVariant &itemVariant, responseList) {
             QVariantMap itemMap = itemVariant.toMap();
             AudioPlaylistItem *item = new AudioPlaylistItem();
-//            item.setFanart(itemMap.value("fanart").toString());
             item->setLabel(itemMap.value("label").toString());
             item->setDuration(QTime().addSecs(itemMap.value("duration").toInt()));
-//            item.setTitle(itemMap.value("title").toString());
             item->setArtist(itemMap.value("artist").toString());
             item->setAlbum(itemMap.value("album").toString());
-//            qDebug() << "adding item:" << item.label();
             m_itemList.append(item);
         }
         endResetModel();
-
-        if(rsp.toMap().value("state").toMap().value("repeat").toString() == "off") {
-            m_repeat = RepeatNone;
-        } else if(rsp.toMap().value("state").toMap().value("repeat").toString() == "one") {
-            m_repeat = RepeatOne;
-        } else {
-            m_repeat = RepeatAll;
-        }
-        emit repeatChanged();
-
-
-        m_shuffle = rsp.toMap().value("state").toMap().value("shuffled").toBool();
-        emit shuffleChanged();
-
-        m_currentItem = rsp.toMap().value("state").toMap().value("current").toInt();
-        qDebug() << "set current to" << m_currentItem;
-        queryItemData(m_currentItem);
         emit countChanged();
-        emit currentChanged();
         break;
     }
     case RequestCurrentData: {
+        xDebug(XDAREA_PLAYLIST) << "Current item data response" << rsp.toMap();
         if(m_itemList.count() > m_currentItem && m_currentItem > -1) {
             AudioPlaylistItem *item = m_itemList.at(m_currentItem);
             QVariantList responseList = rsp.toMap().value("items").toList();
             QVariantMap itemMap = responseList.first().toMap();
-    //            item.setFanart(itemMap.value("fanart").toString());
             item->setLabel(itemMap.value("label").toString());
             item->setTitle(itemMap.value("title").toString());
             item->setArtist(itemMap.value("artist").toString());
