@@ -27,8 +27,6 @@ class Shares : public XbmcLibrary
 public:
     explicit Shares(const QString &mediatype);
 
-    int rowCount(const QModelIndex &parent) const;
-    QVariant data(const QModelIndex &index, int role) const;
     XbmcModel *enterItem(int index);
     void playItem(int index);
     void addToPlaylist(int index);
