@@ -29,20 +29,26 @@ class Songs : public XbmcLibrary
 public:
     explicit Songs(int artistid = -1, int albumid = -1, XbmcModel *parent = 0);
 
-    int rowCount(const QModelIndex &parent) const;
-    QVariant data(const QModelIndex &index, int role) const;
-
     XbmcModel* enterItem(int index);
     void playItem(int index);
     void addToPlaylist(int index);
 
     QString title() const;
+    Q_INVOKABLE void fetchItemDetails(int index);
+    Q_INVOKABLE bool hasDetails() { return true; }
 
 private slots:
-    void responseReceived(int id, const QVariantMap &rsp);
+    void responseReceived(int id, const QVariantMap &map);
 
 private:
-    int m_requestId;
+    enum Request {
+        RequestList,
+        RequestDetails
+    };
+
+    QMap<int, Request> m_requestList;
+    QMap<int, int> m_detailsRequestMap;
+
     int m_artistId;
     int m_albumId;
 };
