@@ -93,7 +93,7 @@ XbmcConnectionPrivate::XbmcConnectionPrivate(QObject *parent) :
     QObject::connect(m_socket, SIGNAL(connected()), SLOT(slotConnected()));
     QObject::connect(m_socket, SIGNAL(disconnected()), SLOT(slotDisconnected()));
 
-    m_timeoutTimer.setInterval(1000);
+    m_timeoutTimer.setInterval(5000);
     m_timeoutTimer.setSingleShot(true);
     QObject::connect(&m_timeoutTimer, SIGNAL(timeout()), SLOT(clearPending()));
 
@@ -237,6 +237,7 @@ void XbmcConnectionPrivate::replyReceived()
 
         if(rsp.value("id").toInt() == m_versionRequestId) {
             // If the remote xbmc has the version field not compiled in, assume its the latest known one
+            xDebug(XDAREA_CONNECTION) << "Parsing XBMC version:" << rsp.value("result").toMap().value("version");
             if(rsp.value("result").toMap().value("version").toMap().value("revision").toString() == "Unknown") {
                 m_xbmcVersion.setDate(2011, 10, 8);
                 qDebug() << "WARNING: Cannot determine Xbmc version. Assuming" << m_xbmcVersion.toString(Qt::SystemLocaleLongDate);
@@ -425,7 +426,6 @@ QString XbmcConnectionPrivate::connectionError()
 
 void XbmcConnectionPrivate::authenticationRequired(QNetworkReply *reply, QAuthenticator *authenticator)
 {
-    Q_UNUSED(reply)
     if(reply == m_lastAuthRequest) {
         m_connectionError = "Wrong username or password";
         emit m_notifier->connectionChanged();
