@@ -19,15 +19,19 @@
 #ifndef XBMCMODEL_H
 #define XBMCMODEL_H
 
+#include "xbmcmodelitem.h"
+
 #include <QAbstractItemModel>
-#include <QStandardItem>
+#include <QDebug>
 
 class XbmcModel : public QAbstractItemModel
 {
     Q_OBJECT
     Q_PROPERTY(QString title READ title NOTIFY titleChanged)
+    Q_PROPERTY(int count READ rowCount NOTIFY layoutChanged)
 public:
     enum Roles {
+        RoleTitle = Qt::DisplayRole,
         RoleFileType = Qt::UserRole + 1,
         RoleSubtitle = Qt::UserRole + 2,
         RoleDuration = Qt::UserRole + 3,
@@ -41,7 +45,30 @@ public:
         RoleTvShowId = Qt::UserRole + 105,
         RoleSeasonId = Qt::UserRole + 106,
         RoleEpisodeId = Qt::UserRole + 107,
-        RoleMusicVideoId = Qt::UserRole + 108
+        RoleMusicVideoId = Qt::UserRole + 108,
+        RoleThumbnail = Qt::UserRole + 109,
+        RoleSortingTitle = Qt::UserRole + 110,
+        RolePlot = Qt::UserRole + 111,
+        RoleRating = Qt::UserRole + 112,
+        RoleSeason = Qt::UserRole + 113,
+        RoleEpisode = Qt::UserRole + 114,
+        RoleFirstAired = Qt::UserRole + 115,
+        RoleGenre,
+        RoleYear,
+        RoleDirector,
+        RoleTagline,
+        RoleMpaa,
+        RoleDescription,
+        RoleInstrument,
+        RoleStyle,
+        RoleMood,
+        RoleBorn,
+        RoleFormed,
+        RoleDied,
+        RoleDisbanded,
+        RoleComment,
+        RolePlaycount,
+        RoleCast
     };
 
     explicit XbmcModel(XbmcModel *parent = 0);
@@ -56,12 +83,19 @@ public:
 
     Q_INVOKABLE int findItem(const QString &string, bool caseSensitive = false);
 
+    Q_INVOKABLE virtual int rowCount(const QModelIndex &parent = QModelIndex()) const
+    {
+        Q_UNUSED(parent)
+        return m_list.count();
+    }
+
 signals:
     void titleChanged();
+    void layoutChanged();
 
 protected:
     XbmcModel *m_parentModel;
-    QList<QStandardItem*> m_list;
+    QList<XbmcModelItem*> m_list;
 };
 
 #endif // XBMCMODEL_H
